/**
  @file commandes.h
  Entete de commandes.c
*/

#ifndef COMMANDES_H
#define COMMANDES_H

#include "lib_ksinu.h"
#include "interpreteur.h"
#include "fifo.h"
#include "signaux.h"

/**************************************************************************************
 Fait par Ouachani Mourad
**************************************************************************************/

/// Execute l'instruction CPILE
int cmd_cpile(int pid,mot_t mot);

/// Execute l'instruction DPILE
int cmd_dpile(int pid,mot_t mot);


/**************************************************************************************
 Fait par Martin Ludovic
**************************************************************************************/

/// Commande pour fixer la taille de la zone de donnees.
int cmd_donnees(int pid,mot_t mot);

/// Execute l'instruction AFFECTE ref = ref_cst.
int cmd_affect(int pid,mot_t mot);

/// Execute l'instruction AFFECTE+ ref += ref_cst
int cmd_affectp(int pid,mot_t mot);

/// Execute l'instruction AFFECTESP
int cmd_affectsp(int pid,mot_t mot);

/// Execute l'instruction TEST.
int cmd_test (int pid,mot_t mot);

/// Execute l'instruction SI.
int cmd_si(int pid,mot_t mot);

/// Execute l'instruction SAUT.
int cmd_saut(int pid,mot_t mot);

/// Commande d'appel de fonction
int cmd_appel(int pid,mot_t mot);

/// Commande de retour de fonction
int cmd_retour(int pid);

/// Commande TRAPPE terminant le processus
int cmd_fin(int pid);

/// Commande TRAPPE qui retourne le pid du processus.
int cmd_id(int pid);

/// Commande TRAPPE qui retourne le ppid du processus.
int cmd_idp(int pid);

/// Commande TRAPPE qui associe un handler a un signal pour le processus.
int cmd_capture(int pid);

/// Commande TRAPPE qui envoie a un processus un signal
int cmd_emets(int pid);

/// Commande TRAPPE qui recouvre l'espace memoire d'un processus pour executer un autre programme
int cmd_recouvre(int pid);

/// Commande TRAPPE qui duplique l'espace memoire\n
int cmd_clone(int pid);

/// Commande TRAPPE qui suspend le processu jusqu' la mort d'un fils
int cmd_attends(int pid);

/// Commande TRAPPE qui lit une lettre ds le tube d'entree
int cmd_lit(int pid);

/// Commande TRAPPE qui ecrit une lettre ds le tube de sortie
int cmd_ecrit(int pid);

/// Termine un processus proprement
int terminer_proc (int pid);

/// Supprime un proc et les pages mem attachees
int supprimer_proc (int pid);

/// Supprime les pages mem attachees au processus
int supprimer_partie_proc (int pid);

/// Regarde l'etat du drapeau du saut conditionnel
int condition_vraie (mot_t mot);

/// Modifie l'etat du drapeau du saut conditionnel
int changer_condition (int condition, mot_t mot);

/// Structure correspondant a un parametre de commande
struct parametre {
  int zone;        ///< Zone (Z_DONNEES ou Z_PILE) ou se trouve la donnee
  int ad;          ///< Adresse dans cette zone
  int type;        ///< Donnee de type constante (P_CONST) ou reference (P_REF)
};
typedef struct parametre param_t;

#define P_CONST 0
#define P_REF 1
#define P_DIRECT 0
#define P_INDIR 1

/// Parse un mot contenant une instruction
int parser_param (int pid, mot_t mot, param_t tab_param[2], int nb);


#endif
