/**
 * @file systeme.h
 * @brief Entete de systeme.c
 */

#ifndef SYSTEME_H
#define SYSTEME_H

#include "interpreteur.h"
#include "fifo.h"
#include "commandes.h"


/**************************************************************************************
 Fait par Martin Ludovic
**************************************************************************************/

 /// Initialise la memoire principale
void init_mem ();

/// Initialise la memoire secondaire (swap)
int init_swap ();

/// Lancement d'un programme
int lancer_prog (char* fic, int pid);



/**************************************************************************************
 Fait par Ouachani Mourad
**************************************************************************************/

/// Handler interceptant SIGUSR1
void top_horloge_handler (int sig);

/// Handler interceptant SIGUSR2
void interface_handler (int sig);

/*************************************************
 Liste des commandes
**************************************************/

#define LP 1
#define STDIN 2
#define QUANTUM 3
#define CADANCE 4
#define HORLOGE 5
#define LPT 6
#define PPP 7
#define PSIG 8
#define SIG 9
#define FIFO_NAME "fifo.f"

/**************************************************
 Structures pour les messages
***************************************************/

/// Structure representant un message a lire ou a ecrire ds le tube
typedef struct message {
  int commande; ///<la commande a executer
  char ref[12]; ///<la reference en argument 
  int int_opt;  ///< argument optionnel
  int int_opt2; ///<argument optionnel (generalement pour les signaux)
} message; 

pid_t pid;
int fifo;

///Lis dans le tube
int lire_tube();

///Ecris dans le tube
int ecrit_tube(struct message mes);

/// Ecrit une chaine de caractre dans le tampon d'entree dun processus
int modif_process(int num_proc, char *ref);

/// Affiche tous les processus et leur etats
int liste_process();

///Affiche le contenue de la table des processus
int printtp(pid_t pid);

/// Ecrire le contenue d'une page physique dans un fichier 
int printpp(int num_pp);

/// Afficher les signaux 
int  printsig(int num_sig);

/// Envoyer un signal a un processus 
int signal_proc(int num_sign,int num_proces);

///Interprete une commande lus dans le tube 
int  interprete_commande(message mes);

#endif
